#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-Lc5EMEAoOwxC7zkEvsfGfr
key:                  pantry-0.8.3-Lc5EMEAoOwxC7zkEvsfGfr
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  ee31adc372abfa7590f0f24a03eb1761
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-Lc5EMEAoOwxC7zkEvsfGfr
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W
    ansi-terminal-1.1-4r9UE8W85hy3ofo15nhM3F base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-2C3GGBWGSyn7RDAiC0wQ7K
    casa-types-0.0.3-39Tk5Zdop2SKHbuFgGBh1Z
    conduit-1.3.6.1-KgvxRslmDgl5Hh23ckCIr4
    conduit-extra-1.3.8-Jj0kbw13PEN4kqtz5CpH4f containers-0.6.7
    crypton-1.0.4-G4xkZQ2ryEnF9uR2K08A4i
    crypton-conduit-0.2.3-HPsXw7TryKn2MaQwNf2VnR
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-CugiVGvp2f7CkrgPqazzVJ
    generic-deriving-1.14.7-KdgoTsokjncGxVD4ARzTSh
    hackage-security-0.6.3.2-Lpzv1VkK3sU1c26wArWiLa
    hpack-0.38.0-E9thsL6VIf5HkZCva2u1Ir
    http-client-0.7.19-5ssHakQzOHODxkRAhbUNfr
    http-client-tls-0.3.6.4-9qZl85bdUY1LG6630xexvr
    http-conduit-2.3.9.1-BnucNaPs7sXAEbK0NPLd85
    http-download-0.2.1.0-AvN2PH9zZmoL81IxLRdMXa
    http-types-0.12.4-EOP8M0z2aoj67cPO54IyNv
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-Dqmf2XZhpKk16ZGQymmkCW
    path-0.9.6-3eGlt3YjUoEGiEZbVETSwW
    path-io-1.8.2-GjSrcuMPyGiLIcBVNYzh2H
    persistent-2.14.5.2-IC6ObWv63c5yGhlklCrkD
    persistent-sqlite-2.13.2.0-H4YvU7xOjUy4hrnr9NcAyK
    primitive-0.9.1.0-F34wLx58ciG566Ovm12rcF
    resourcet-1.2.6-FMG404WUxrdL7VHJswAKQ6
    rio-0.1.24.0-BUQLdvBEYMEH25LnuYesKC
    rio-orphans-0.1.2.0-GGr00Ot1uqj5AJpy2QLirt
    rio-prettyprint-0.1.8.0-E2wC2FhLmAiDpISkuQLswE
    tar-conduit-0.4.1-6Eq1L1x5FskT7ZyJ0IsgQ text-2.0.2
    text-metrics-0.3.3-H63b8EZmNL94lJxeyNEou3 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-5rXwzu0vMWVWC5G5Ppx8z
    unliftio-0.2.25.1-GGj9GPgXezm8HQgfatElxR
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ
    yaml-0.11.11.2-AFgDcerI3uxKYppYy0BSeM
    zip-archive-0.4.3.2-DNL7vWB3PuWFX6kOKC5cg7

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

